############# Script for statistical analyses and figures in:
############# Gingins et al. (2018, PeerJ). The performance of cleaner wrasse, Labroides dimidiatus, in a reversal learning task varies across experimental paradigms.
############# For questions or to notify the authors if any errors are identified in the data, please contact Simon Gingins (simongingins@gmail.com).
######################################################################################################################################################################

library(survival)
library (coxme)
library(survminer)


spat <- read.table("Spatial-FINAL.txt", header=T)

###### PLOTS

spat$treatmentplot <- factor(spat$treatment, levels=c(2,3,1,4), labels=c("clear-lift", "clear-stay", "opaque", "large tank"), ordered=T) # creating a factor for the treatments ordered in the way we want to plot them


# plotting the main figure
setEPS()
postscript("Figure2.eps", width=10, height= 6)

par(mfrow=c(1,2))

stripchart(spat$trials_1~spat$treatmentplot, cex=1.4, col="red", method="stack", offset=0.5, pch=20, vertical=T, data=spat, xaxt="n", ylab="Number of trials", main="a) Initial spatial task", font.main = 1, ylim=c(0,110))
axis(side=1, at=c(1.2, 2.15, 3.05, 4.05), labels=c("clear-lift", "clear-stay", "opaque", "large tank"), cex.axis=1.1)
abline(95, 0, lty="dashed")

stripchart(spat$trials_2~spat$treatmentplot, cex = 1.4, col="blue", method="stack", offset=0.5, pch=20, vertical=T, data=spat, xaxt="n", ylab="Number of trials", main="b) Reversal task", font.main = 1, ylim=c(0,110), xlog=F)
axis(side=1, at=c(1.2, 2.15, 3.05, 4.05), labels=c("clear-lift", "clear-stay", "opaque", "large tank"), cex.axis=1.1)
abline(95, 0, lty="dashed")
text(c(1.33, 2.27, 3.1, 4.1),c(108), labels=c("a", "ab", "c", "bc"), cex = 1.2)
dev.off()

### MEANS per treatment

spatsub <- subset(spat, solved_1==1)
spatsub2 <- subset(spatsub, solved_2==1)

mean(spatsub$trials_1)
mean(spatsub[spatsub$treat_details=="clear-lift",]$trials_1)
mean(spatsub[spatsub$treat_details=="clear-stay",]$trials_1)
mean(spatsub[spatsub$treat_details=="opaque",]$trials_1)
mean(spatsub[spatsub$treat_details=="large-tank",]$trials_1)

mean(spatsub2$trials_2)
mean(spatsub2[spatsub2$treat_details=="clear-lift",]$trials_2)
mean(spatsub2[spatsub2$treat_details=="clear-stay",]$trials_2)
mean(spatsub2[spatsub2$treat_details=="opaque",]$trials_2)
mean(spatsub2[spatsub2$treat_details=="large-tank",]$trials_2)

#################################
### Survival analysis
#################################


# testing the proportional hazards assumption for a coxph model
model1 <- coxph(Surv(spat$trials_1, spat$solved_1, type='right', origin=0)~spat$treatment)
cox.zph(model1)

model2 <- coxph(Surv(spat$trials_2, spat$solved_2, type='right', origin=0)~spat$treatment)
cox.zph(model2)

# for the reversal experiment, the proportional hazards assumtion is not fulfilled
# therefore we use the non-parametric survdiff() log-rank test below instead of the parametric coxph() test

# survival analysis for the initial spatial task
model3 <- survdiff(Surv(spat$trials_1, spat$solved_1, type='right', origin=0)~spat$treatment)
model3

# survival analysis for the reversal spatial task
model4 <- survdiff(Surv(spat$trials_2, spat$solved_2, type='right', origin=0)~spat$treatment)
model4


# obtaining the p-values for pairwise comparisons for the reversal experiment

pairwise_survdiff(Surv(trials_2, solved_2, type='right', origin=0)~treatment, data = spat, p.adjust.method = "BH", rho = 0)

#################################################################################
######### investigating the potential correlation across reversal & initial tasks
#################################################################################


# plotting performance in initial task VS reversal

par(mfrow=c(1,2))
plot(spat$trials_1,spat$trials_2, xlab="Score Initial Task", ylab="Score Reversal Task")
abline(lm(spat$trials_1~spat$trials_2))

perf <- c(spat$trials_1, spat$trials_2)
reversal <- c(rep("initial", length(spat$trials_1)), rep("reversal", length(spat$trials_2)))
ids <- c(spat$fish_ID, spat$fish_ID)
interaction.plot(reversal, ids, perf, pch=1, type="b", legend=F, col = "black", lty=1, xlab="Task", ylab="Score")

# testing the correlation

cor.test(spat$trials_2, spat$trials_1, method="kendall")

##################################################################
######### checking for the potential effect of initial side reward
##################################################################


subspat <- subset(spat, !is.na(spat$start_side)) #removing the missing values from the dataset (i.e. 6 fish for which we lost the initial rewards side)
subspat
######## initial spatial task

model5 <- survdiff(Surv(trials_1, solved_1, type='right', origin=0)~treatment, data = subspat)
model5.1 <- survdiff(Surv(trials_1, solved_1, type='right', origin=0)~start_side, data = subspat)
model5.2 <- survdiff(Surv(trials_1, solved_1, type='right', origin=0)~treatment + start_side, data = subspat)

print(model5)
print(model5.1)
print(model5.2)

# using Coxph, which allows integrating the interaction

model5.3 <- coxph(Surv(trials_1, solved_1, type='right', origin=0)~treatment * start_side, data = subspat)
cox.zph(model5.3)
summary(model5.3)

###### reversal spatial task

model6 <- survdiff(Surv(trials_2, solved_2, type='right', origin=0)~treatment, data = subspat)
model6.1 <- survdiff(Surv(trials_2, solved_2, type='right', origin=0)~start_side, data = subspat)
model6.2 <-survdiff(Surv(trials_2, solved_2, type='right', origin=0)~treatment + start_side, data = subspat)

print(model6)
print(model6.1)
print(model6.2)

# using Coxph, which allows integrating the interaction. 
# However, we note that the data on the reversal learning does not meet the proportional hazards assumption (tested with cox.zph()).
# Therefore, the Coxph test cannot be used.

model6.3 <- coxph(Surv(trials_2, solved_2, type='right', origin=0)~treatment * start_side, data = subspat)
cox.zph(model6.3)

